@@ -1,6 +1,7 @@
 """Some common helper functions for the test suite."""
 
 import re
+import sphinx
 
 RE_ID = r'[a-z][-?a-z0-9]*'
 RE_NUM = r'\d+'
@@ -13,7 +14,7 @@ def html_citation_refs(refid=RE_ID, label=RE_LABEL):
     return re.compile(
         r'<a class="reference internal" '
         r'href="(?P<refdoc>[^#]+)?#(?P<refid>{refid})">'
-        r'<span>(?P<label>{label})</span>'
+        r'(?P<label>{label})'
         r'</a>'.format(refid=refid, label=label))
 
 
@@ -59,11 +60,19 @@ def html_footnotes(id_=RE_ID, text=RE_TEXT):
 
 def latex_citations(docname=RE_DOCNAME, id_=RE_ID,
                     label=RE_LABEL, text=RE_TEXT):
-    return re.compile(
-        r'\\bibitem\[(?P<label>{label})]'
-        r'{{(?P<docname>{docname}):(?P<id_>{id_})}}\n'
-        r'(?P<text>{text})\n'.format(
-            docname=docname, label=label, id_=id_, text=text))
+    if sphinx.version_info < (3, 5):
+        return re.compile(
+            r'\\bibitem\[(?P<label>{label})]'
+            r'{{(?P<docname>{docname}):(?P<id_>{id_})}}\n'
+            r'(?P<text>{text})\n'.format(
+                docname=docname, label=label, id_=id_, text=text))
+    else:
+        return re.compile(
+            r'\\bibitem\[(?P<label>{label})]'
+            r'{{(?P<docname>{docname}):(?P<id_>{id_})}}\n'
+            r'\\sphinxAtStartPar\n'
+            r'(?P<text>{text})\n'.format(
+                docname=docname, label=label, id_=id_, text=text))
 
 
 def latex_citation_refs(docname=RE_DOCNAME, refid=RE_ID):
