@@ -46,7 +46,7 @@ ROLES = [
 ]
 
 
-def parse_keys(rawtext):
+def parse_keys(rawtext) -> Tuple[List[str], str, str]:
     # Get the keys and any pre- and post-citation text
     # Spaces nor commas are allowed in cite keys, so we split on commas
     # first.  This will give us a list of keys, however, the last item may have
@@ -80,7 +80,7 @@ def parse_keys(rawtext):
         else:
             k = k[0]
         keys.append(k)
-    return (keys, pre, post)
+    return keys, pre, post
 
 
 class Citations(object):
@@ -92,13 +92,10 @@ class Citations(object):
         self.parser = None
         self.data = None
         self.ref_map = {}
-
-        file_name = env.relfn2path(self.conf.get('file'),
-                                   env.app.config.master_doc)[1]
-        if file_name:
-            self.file_name = file_name
-            self.parser = bibtex.Parser()
-            self.data = self.parser.parse_file(self.file_name)
+        self.file_name = env.relfn2path(self.conf['file'],
+                                        env.app.config.master_doc)[1]
+        self.parser = bibtex.Parser()
+        self.data = self.parser.parse_file(self.file_name)
 
     def get(self, key):
         return self.data.entries.get(key)
@@ -127,9 +124,7 @@ class CitationTransform(object):
         return ','.join([r.key for r in self.refs])
 
     def get_ref_num(self, key):
-        for i, k in enumerate(self.global_keys):
-            if k == key:
-                return i + 1
+        return list(self.global_keys.keys()).index(key) + 1
 
     def get_author(self, authors, all_authors=False):
         if len(authors) == 0:
@@ -146,13 +141,12 @@ class CitationTransform(object):
         author = author.replace('}', '')
         return author
 
-    def cite(self, cmd, refuri, global_keys=None):
+    def cite(self, cmd, refuri, global_keys):
         """
         Return a docutils Node consisting of properly formatted citations
         children nodes.
         """
-        if global_keys is not None:
-            self.global_keys = global_keys
+        self.global_keys = global_keys
         bo, bc = self.config['brackets']
         sep = u'%s ' % self.config['separator']
         style = self.config['style']
@@ -275,7 +269,7 @@ class CitationXRefRole(XRefRole):
         if self.name == "cite:text":
             # A ``text`` citation is unique because it doesn't reference a
             # cite-key
-            keys = []
+            keys: List[str] = []
             pre, post = self.text, ''
         else:
             keys, pre, post = parse_keys(self.text)
